# How to build your site

## Run Development Server

``` shell
papery run
```

You can see web site resources in ouput directory.

And you can preview with development server via <http://127.0.0.1:8000/>

## Build manually

``` shell
papery build
```
